@@ -624,7 +624,7 @@ def _send_compute_job(function_info, args, kwargs, timeout=3600):
         "x-api-key": api_key
     }
 
-    endpoint = f"{NERD_COMPUTE_ENDPOINT}/compute"
+    endpoint = f"{NERD_COMPUTE_ENDPOINT}/data"
 
     job_id = str(uuid.uuid4())
     request_payload = {
